@@ -1,3 +1,4 @@
+import re
 import datetime
 import logging
 import threading
@@ -24,7 +25,9 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                  **kwargs,
                  ):
         """
-        An action that is configured for execution
+        An action that is configured for execution. Arguments and Keyword arguments may be specified and will
+        be handed to the action on execution unless overridden by the user. (Using kwargs over args is strongly
+        recommended.)
 
         :param action: action to perform (callable)
         :param args: arguments for the action
@@ -51,9 +54,8 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         if configuration_name is None:
             configuration_name = self._generate_unique_name(self.action)
         else:
-            if configuration_name in self.get_configuration_names():
-                raise NameError(f'The configuration name "{configuration_name}" is already used, please choose a '
-                                f'unique name for the configuration. ')
+            # ensure configuration name is unique
+            configuration_name = self._generate_unique_name(configuration_name)
         self.name = configuration_name
         if next_action is not None:
             self.next_action = next_action
@@ -136,21 +138,25 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         ]
 
     @classmethod
-    def _generate_unique_name(cls, action: Action) -> str:
+    def _generate_unique_name(cls, name: Union[Action, str]) -> str:
         """
         Generates a unique numbered name based on an Action instance. The resulting name will be unique in the
         registry.
 
-        :param action: action to base naming off of
+        :param name: name to base off of
         :return: generated name
         """
+        if isinstance(name, Action):
+            name = name.name
+        elif re.match('.+[_\s]\d+', name) is not None:
+            name = re.match('(?P<base_name>.+)[_\s]\d+', name).group('base_name')
         i = 2
         current_names = cls.get_configuration_names()
-        if action.name not in current_names:
-            return action.name
+        if name not in current_names:
+            return name
         while True:
-            target_name = f'{action.name}_{i}'
-            if f'{action.name}_{i}' not in current_names:
+            target_name = f'{name}_{i}'
+            if f'{name}_{i}' not in current_names:
                 return target_name
             i += 1
 
@@ -306,7 +312,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
 class ConfiguredActionList(ActionList):
     def __init__(self, *actions: Union[Action, ConfiguredAction]):
         """
-        A manager for a list of Actions.
+        A manager for a list of Configured Actions.
 
         :param actions: actions to sequence
         """
@@ -524,7 +530,7 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
             out['duration'] = self.time_completed - self.time_started
             if self.error is True:
                 out['error_during_execution'] = True
-                out['error_details'] = self.error_details
+                out['error_details'] = str(self.error_details)
             else:  # if completed and no error, include the method return
                 out['action_return'] = self.action_return
         return out
@@ -600,7 +606,7 @@ class ThreadedTrackedAction(TrackedAction):
         """
         if self.triggered is True:
             raise SystemError(f'multiple executions of the same {self.__class__.__name__} are not supported')
-        logger.info(f'triggering execution of {self.__str__()}')
+        logger.debug(f'triggering execution of {self.__str__()}')
         self.update_args(*args)
         self.update_kwargs(**kwargs)
         self._thread = threading.Thread(
@@ -651,6 +657,11 @@ class ThreadedTrackedAction(TrackedAction):
 
 class TrackedActionList(ActionList):
     def __init__(self, *actions: Union[Action, ConfiguredAction, TrackedAction]):
+        """
+        A manager for a list of Tracked Actions.
+
+        :param actions: actions to sequence
+        """
         self._action_list: List[TrackedAction] = []
         super().__init__(*actions)
         # todo define what happens when you copy the list (should create unexecuted trackedactions)
